<?php
/**
 * Plugin Name: DMG Privacy
 * Plugin URI: https://github.com/ANMedia/dmg-privacy-wp-plugin
 * Description: Embed the DMG Privacy Policy information via a WP Shortcode
 * Version: 1.1.0
 */

/**
 * A shortcode to output the privacy policy
 */
class DMG_Privacy_Shortcode
{

    const CACHE_KEY = 'dmgmedia_privacy';

    /**
     * Setup the shortcode
     *
     * @return void
     */
    public static function init() {
        add_shortcode('dmgprivacy', array( __CLASS__, 'shortcode' ));
        add_action( 'wp_footer', [__CLASS__, 'add_scripts'] );
    }


    /**
     * Shortcode callback
     *
     * @param  array $atts The shortcode attributes
     * @return string The HTML markup to output
     */
    public static function shortcode( $atts ) {
        $atts = shortcode_atts(
            array(
            'id'  => false,
            'url' => 'https://dmgmedia.co.uk/wp-json/wp/v2/privacy-policy/',
            'col' => '#efefef'
            ),
            $atts
        );
        
        if ( empty( $atts['id'] ) ) {
           return;
        }

        $header_bg_color = '#efefef';
        // Allow for a custom color override for accodian headers via shortcode attribute, `col`
        if( preg_match('/^#[a-f0-9]{6}$/i', $atts['col']) ) {
            $header_bg_color = $atts['col'];
        } elseif ( preg_match('/^[a-f0-9]{6}$/i', $atts['col'] ) )  {
            $header_bg_color = '#' . $atts['col'];
        }


        $cached_data = get_transient( self::CACHE_KEY );

        // Return cached output if we have it, otherwise fetch new data
        if (! empty($cached_data) ) {
            $data = $cached_data;
        } else {
            $url      = $atts['url'] . $atts['id'];
            // phpcs:ignore
            $response = wp_remote_get( $url );
            $body     = wp_remote_retrieve_body( $response );
            $data     = json_decode( $body );
        }


        if ( !is_wp_error( $data ) && !empty( $data ) ) {
            
            $last_updated = gmdate("d F Y", strtotime( $data->acf->last_updated ) );
            $prev_version =  gmdate("d F Y", strtotime( $data->acf->previous_version) );
            $policy_intro_text = str_replace(["\r\n\r\n","\n\n"], ['</p><p>','</p><p>'], wp_kses_post( $data->acf->introduction ) );
            $cookie_settings_text = str_replace(["\r\n\r\n","\n\n"], ['</p><p>','</p><p>'], wp_kses_post( $data->acf->cookie_settings ) );
            $iframe_src = ( ! empty($data->acf->dsr_form_url) ) ? $data->acf->dsr_form_url : '';
            
            ob_start();
            ?>
            <div class="dmg-privacy">
                <h1 class="dmg-privacy__title"><?php echo wp_kses_post( $data->title->rendered ); ?></h1>
                <h2 class="dmg-privacy__subtitle">Privacy & Cookies Policy (the “Policy”)</h2>
                <h3 class="dmg-privacy__last-updated">Last updated: <?php echo esc_attr( $last_updated ); ?></h3>
                <h3 class="dmg-privacy__previous-version">Previous version: <?php echo esc_attr( $prev_version ); ?></h3>
                <p class="dmg-privacy__intro-text"><?php echo wp_kses_post( $policy_intro_text ); ?></p>
                <p class="dmg-privacy__cookie-text"><?php echo wp_kses_post( $cookie_settings_text ); ?></p>
                
                <div id="dmg-privacy__popup" class="dmg-privacy__popup dmg-privacy__popup--hidden">
                    <div class="dmg-privacy__popup__inner">
                        <div id="dmg-privacy__popup__close" class="dmg-privacy__popup__close">Close</div>
                        <iframe src="<?php echo esc_url( $iframe_src ); ?>" height="100%" width="100%"></iframe>
                   </div>
                </div>
                <p><a href="<?php esc_url( $iframe_src ); ?>" id="dmg-privacy__submit" class="dmg-privacy__submit">Submit Data Subject Request</a></p>
           
                <div class="dmg-privacy__accordion">
                <?php
                if (! empty($data->acf->privacypolicy) ) :
                    foreach ( $data->acf->privacypolicy as $block ) :
                        ?>
                    <h3 style="background-color:<?php echo esc_attr( $header_bg_color ); ?>" class="dmg-privacy__accordion__section"><?php echo esc_attr( $block->tab_title ); ?></h3>
                    <div class="dmg-privacy__accordion__panel"><?php echo wp_kses_post( wpautop( $block->tab_content ) ); ?></div>
                        <?php
                    endforeach;
                endif;
                ?>
                </div>
            </div>
           <?php
            // Cache the resulting markup
            set_transient( self::CACHE_KEY, $data, (15 * MINUTE_IN_SECONDS) );
        } else {
            return '<!-- Error requesting ' . esc_url( $url ) . ' -->';
        }
    


        return ob_get_clean();

    }

    /**
     * Print the CSS and JS
     *
     * @return void
     */
    public static function add_scripts(){
        if( is_page() && has_shortcode( get_the_content(), 'dmgprivacy' ) ) {
            // inline and minify style and script
            $css_file_contents = file_get_contents(__DIR__ . '/dmg-privacy-policy.css');
            if( !empty( $css_file_contents ) ) {
                $css_file_contents = str_replace(["\r\n", "\r", "\n", "\t", '  ', '    ', '    '], '', $css_file_contents);
                echo '<style>' . $css_file_contents . '</style>';
            }

            $js_file_contents = file_get_contents(__DIR__ . '/dmg-privacy-policy.js');
            if( !empty( $js_file_contents ) ) {
                echo '<script>' . $js_file_contents . '</script>';
            }
        }

    }
}

DMG_Privacy_Shortcode::init();
